import React from 'react';
import { Trans, TransTitle } from '@ui-schema/ui-schema';
import MenuItem from '@mui/material/MenuItem';
import Select from '@mui/material/Select';
import { CodeBar } from '@ui-schema/material-code/CodeBar';
import { Box } from '@mui/material';
import FormLabel from '@mui/material/FormLabel';
import { ValidityHelperText } from '@ui-schema/ds-material/Component/LocaleHelperText';
export const WidgetCodeSelectable = ({
  storeKeys,
  schema,
  value,
  onChange,
  valid,
  required,
  errors,
  showValidity,
  readOnly: readOnlyProp,
  CodeMirror,
  extensions,
  formatValue,
  formatKey,
  valueKey,
  barContent,
  barEnd,
  selectSize = 'small',
  onChangeFormat,
  CodeBar: CustomCodeBar
}) => {
  var _schema$get;

  const handleOnChange = React.useCallback((editor, newValue) => {
    if (!editor.docChanged || typeof newValue !== 'string') {
      return;
    }

    onChange({
      storeKeys: storeKeys.push(valueKey),
      scopes: ['value'],
      type: 'set',
      data: {
        value: newValue
      },
      schema,
      required
    });
  }, [onChange, storeKeys, schema, required, valueKey]);
  const handleOnChangeFormat = React.useCallback(e => {
    if (onChangeFormat) {
      onChangeFormat(e.target.value);
    }

    onChange({
      storeKeys: storeKeys.push(formatKey),
      scopes: ['value'],
      type: 'set',
      data: {
        value: e.target.value
      },
      schema,
      required
    });
  }, [onChange, onChangeFormat, storeKeys, schema, required, formatKey]);
  const hideTitle = schema === null || schema === void 0 ? void 0 : schema.getIn(['view', 'hideTitle']);
  const readOnly = readOnlyProp || (schema === null || schema === void 0 ? void 0 : schema.get('readOnly'));
  const classNamesContent = React.useMemo(() => valid ? undefined : ['invalid'], [valid]);
  const CodeBarComp = CustomCodeBar || CodeBar;
  return React.createElement(React.Fragment, null, hideTitle ? null : React.createElement(Box, {
    mb: 0.5
  }, React.createElement(FormLabel, {
    error: !valid && showValidity
  }, React.createElement(TransTitle, {
    storeKeys: storeKeys,
    schema: schema
  }), required ? ' *' : null)), React.createElement(CodeMirror, {
    value: value || '',
    onChange: readOnly ? undefined : handleOnChange,
    extensions: extensions,
    classNamesContent: classNamesContent,
    dense: schema.getIn(['view', 'dense'])
  }), React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }), React.createElement(CodeBarComp, {
    schema: schema,
    barBegin: React.createElement(Select, {
      onChange: handleOnChangeFormat,
      value: formatValue || '',
      size: selectSize,
      disabled: readOnly
    }, schema === null || schema === void 0 ? void 0 : (_schema$get = schema.get('format')) === null || _schema$get === void 0 ? void 0 : _schema$get.map(f => React.createElement(MenuItem, {
      key: f,
      value: f,
      dense: true
    }, React.createElement(Trans, {
      text: 'formats.' + f,
      fallback: f
    })))),
    barContent: barContent,
    barEnd: barEnd
  }));
};